"""Single source to the version across setup.py and the whole project.
"""
from __future__ import unicode_literals
__version__ = '2.4.2'

